aboutsummaryrefslogtreecommitdiff
path: root/lockchain-core/src/users/userstore.rs
diff options
context:
space:
mode:
Diffstat (limited to 'lockchain-core/src/users/userstore.rs')
-rw-r--r--lockchain-core/src/users/userstore.rs13
1 files changed, 7 insertions, 6 deletions
diff --git a/lockchain-core/src/users/userstore.rs b/lockchain-core/src/users/userstore.rs
index 60fee0b..483c4ee 100644
--- a/lockchain-core/src/users/userstore.rs
+++ b/lockchain-core/src/users/userstore.rs
@@ -1,13 +1,14 @@
+//! Merging `KeyStore` and `Userstore` into the same concept
+
use super::rights::Access;
-use super::secrets::SecretType;
use crypto::Key;
use std::collections::HashMap;
/// A thin user keystore
///
/// It's implementation can manage multiple keys per user, of various
/// types and constrained for limited access rights.
-pub struct KeyStore {
+pub struct UserStore {
store: HashMap<String, StoreUser>,
}
@@ -16,11 +17,11 @@ struct StoreUser {
keys: HashMap<Access, Key>,
}
-impl KeyStore {
- /// Create a new, empty keystore
+impl UserStore {
+ /// Create a new, empty UserStore
///
/// This is most likely *not* what you want. Instead, transform
/// a `MetaData` object into a keystore.
pub fn new() -> Self {
Self {
store: HashMap::new(),
@@ -1,13 +1,14 @@
use crypto::Key;
use std::collections::HashMap;
-/// A thin user keystore
+/// A thin user UserStore
///
/// It's implementation can manage multiple keys per user, of various
@@ -16,11 +17,11 @@ struct StoreUser {
///
/// This is most likely *not* what you want. Instead, transform
- /// a `MetaData` object into a keystore.
+ /// a `MetaData` object into a UserStore.
pub fn new() -> Self {
Self {